@@ -1,10 +1,14 @@
 #
 #spread display and analisys
 #
-from qt import *
+#try:
+#    from PyQt4.QtGui import *
+#except ImportError: 
+#    print "Please install PyQT 4"
+#from qt import *
 from xml.dom import minidom, Node
-import dgraph, crypt, os, string
-import visual as V
+import os, string
+#import visual as V
 from math import *
 from numpy import *
 import codecs
@@ -14,9 +18,11 @@ class Spread:
         self.g = graphobj
         self.outdir = outdir
         self.encoding = encoding
-        ct = self.cleanTree()
+#        ct = self.cleanTree()
         #self.dotDraw(ct)
-        self.writeGML(ct,outdir,encoding)
+#        self.writeGML(ct,outdir,encoding)
+        graphml = GraphML(self.g, outdir, encoding)
+        graphml.write()
     
     def cleanTree(self):
         """
@@ -30,7 +36,7 @@ class Spread:
             if len(infectors):
                 reverse_infectors = [ [v[1],v[0]] for v in infectors.items()]
                 reverse_infectors.sort()
-                mli = [reverse_infectors[j][1] for j in range(0,len(reverse_infectors))][-1]#Most likely infector
+                mli = [reverse_infectors[j][1] for j in xrange(0,len(reverse_infectors))][-1]#Most likely infector
             else:
                 mli = 'NA'
             sptree.append((i[0],i[1].sitename,mli))
@@ -54,36 +60,9 @@ class Spread:
         """
         display the epidemic tree
         """
-        self.grd = dgraph.Graph(0.04, name= 'Epidemic Spread Display')
-        #add time label
-        V.label(pos=(0,20,3), text='Time', xoffset=0, yoffset=0, space=5, height=10, border=3, line=0)
-        #add seed
-        seed = dgraph.Node(2,(0,-10,0),r=5)
-        seed.name = self.g.epipath[0][1].sitename
-        nodes=[seed]
-        edges=[]
-        vpos = -10
-
-        for n,i in enumerate(self.g.epipath):
-            x= n*10
-            y = vpos
-            V.label(pos=(x,15,10), text=str(i[0]), xoffset=0, yoffset=0, space=5, height=10, border=3, line=1)
-            nodes.append(dgraph.Node(2,(x,y,0),r=5))
-            nodes[-1].name = i[1].sitename
-            V.label(pos=(x,y,0), text=str(nodes[-1].name), xoffset=5, yoffset=5, space=0, height=10, border=3, line=1)
-            nodes[-1].name = i[1].sitename
-            vpos -= 10
-            if i[2]:
-                for j in i[2].keys():
-                    #print j,i[2],nodes[-1].name
-                    n2 = [k for k in nodes if crypt.crypt(k.name,'ab') == crypt.crypt(j,'ab')][0]
-                    edges.append(dgraph.RubberEdge(nodes[-1],n2,1, damping=.8))
-                    #edges[-1].cylinder.radius = log10(j[0])
-        self.grd.insertNodeList(nodes)
-        self.grd.insertEdgeList(edges)
-        self.grd.centerView()
-
-
+        pass
+        
+        
     def writeGML(self,tree, outdir,encoding,fname="spreadtree.gml"):
         """
         Save the tree in the GML format
@@ -137,6 +116,100 @@ class Spread:
             f.writelines(['\t\t\tfill\t"#000000"\n','\t\t\ttargetArrow\t"standard"\n','\t\t]\n','\t]\n'])
     writeENGML = classmethod(writeENGML)
 
+class GraphML:
+    def __init__(self,graphobj,  outdir, encoding,fname="spread.graphml" ):
+        """
+        Generates a valid GraphML document from the spread tree.
+        """
+        self.g = graphobj
+        self.encoding = encoding
+        self.outdir = outdir
+        self.fname = fname
+        self.doc = minidom.Document()
+        # Creating Root element
+        gml = self.doc.createElement("graphml")
+        gml.setAttribute("xmlns","http://graphml.graphdrawing.org/xmlns")
+        gml.setAttribute("xmlns:xsi", "http://www.w3.org/2001/XMLSchema-instance")
+        gml.setAttribute("xsi:schemaLocation", "http://graphml.graphdrawing.org/xmlns http://graphml.graphdrawing.org/xmlns/1.0/graphml.xsd")
+        self.addAttrKeys(gml)
+        
+        # Creating graph Element
+        self.gr = self.doc.createElement("graph")
+        self.gr.setAttribute("id", "graphname")
+        self.gr.setAttribute("edgedefault", "directed")
+        
+        #Creating nodes and edges
+        self.nodes = []
+        for n in self.g.epipath:
+            infectors = n[-1]
+            self.addNodeEl(n[1].geocode, n[1].sitename)
+            self.nodes.append(n[1].geocode)
+            for  i, c in infectors.iteritems():
+                self.addNodeEl(i.geocode, i.sitename)
+                self.addEdgeEl(i.geocode, n[1].geocode, n[0], c)
+        gml.appendChild(self.gr)
+        self.doc.appendChild(gml)
+                
+    def addNodeEl(self, gc , name):
+        """
+        Adds a Node element to the Graphml object
+        """
+        if gc in self.nodes:
+            return
+        else:
+#            print gc, name
+            nd = self.doc.createElement("node")
+            nd.setAttribute("id", "n"+str(gc))
+            data = self.doc.createElement("data")
+            data.setAttribute("key", "d0")
+            data.appendChild(self.doc.createTextNode(name))
+            nd.appendChild(data)
+            self.gr.appendChild(nd)
+            
+    def addEdgeEl(self, s, d , t, ino):
+#        print s, d , t , ino
+        ed = self.doc.createElement("edge")
+        ed.setAttribute("source", str(s))
+        ed.setAttribute("target", str(d))
+        data = self.doc.createElement("data")
+        data.setAttribute("key", "d1")
+        data.appendChild(self.doc.createTextNode(str(ino)))
+        ed.appendChild(data)
+        data = self.doc.createElement("data")
+        data.setAttribute("key", "d2")
+        data.appendChild(self.doc.createTextNode(str(t)))
+        ed.appendChild(data)
+        self.gr.appendChild(ed)
+    
+    def addAttrKeys(self, gml):
+        k1 = self.doc.createElement("key")
+        k1.setAttribute("id", "d0")
+        k1.setAttribute("for", "node")
+        k1.setAttribute("attr.name", "label")
+        k1.setAttribute("attr.type", "string")
+        gml.appendChild(k1)
+        k2 = self.doc.createElement("key")
+        k2.setAttribute("id", "d1")
+        k2.setAttribute("for", "edge")
+        k2.setAttribute("attr.name", "Innoculum")
+        k2.setAttribute("attr.type", "int")
+        gml.appendChild(k2)
+        k3 = self.doc.createElement("key")
+        k3.setAttribute("id", "d2")
+        k3.setAttribute("for", "edge")
+        k3.setAttribute("attr.name", "timestep")
+        k3.setAttribute("attr.type", "int")
+        gml.appendChild(k3)
+    def write(self):
+        """
+        Writes the graphml file to disk
+        """
+        fullpath = os.path.join(self.outdir,self.fname)
+        f=open(fullpath,"w")
+#        f.write('<?xml version="1.0" encoding="%s"?>'%self.encoding)
+        f.write(self.doc.toprettyxml(encoding=self.encoding))
+        f.close()
+        
 class Consensus:
     def __init__(self,path,cutoff=0.0):
         tl = self.readTress(path)
